'use strict';

var _chai = require('chai');

var _assert = require('assert');

var _assert2 = _interopRequireDefault(_assert);

var _ = require('./');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('detective-typescript', function () {
  var ast = {
    type: 'Program',
    body: [{
      type: 'VariableDeclaration',
      declarations: [{
        type: 'VariableDeclarator',
        id: {
          type: 'Identifier',
          name: 'x'
        },
        init: {
          type: 'Literal',
          value: 4,
          raw: '4'
        }
      }],
      kind: 'let'
    }]
  };

  it('accepts an ast', function () {
    var deps = (0, _2.default)(ast);
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(!depsKeys.length);
  });

  it('retrieves the dependencies of modules', function () {
    var deps = (0, _2.default)('import {foo, bar} from "mylib";');
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(depsKeys.length === 1);
    (0, _chai.expect)(deps).to.have.property('mylib');
  });

  it('retrieves the re-export dependencies of modules', function () {
    var deps = (0, _2.default)('export {foo, bar} from "mylib";');
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(depsKeys.length === 1);
    (0, _chai.expect)(deps).to.have.property('mylib');
  });

  it('retrieves the re-export * dependencies of modules', function () {
    var deps = (0, _2.default)('export * from "mylib";');
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(depsKeys.length === 1);
    (0, _chai.expect)(deps).to.have.property('mylib');
  });

  it('handles multiple imports', function () {
    var deps = (0, _2.default)('import {foo, bar} from "mylib";\nimport "mylib2"');
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(depsKeys.length === 2);
    (0, _chai.expect)(deps).to.have.property('mylib');
    (0, _chai.expect)(deps).to.have.property('mylib2');
  });

  it('handles default imports', function () {
    var deps = (0, _2.default)('import foo from "foo";');
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(depsKeys.length === 1);
    (0, _chai.expect)(deps).to.have.property('foo');
  });

  it('retrieves dependencies from modules using "export ="', function () {
    var deps = (0, _2.default)('import foo = require("mylib");');
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(depsKeys.length === 1);
    (0, _chai.expect)(deps).to.have.property('mylib');
  });

  it('returns an empty list for non modules', function () {
    var deps = (0, _2.default)('var foo = require("foo");');
    var depsKeys = Object.keys(deps);
    (0, _assert2.default)(!depsKeys.length);
  });

  it('returns an empty list for empty files', function () {
    var deps = (0, _2.default)('');
    var depsKeys = Object.keys(deps);
    _assert2.default.equal(depsKeys.length, 0);
  });

  it('throws when content is not provided', function () {
    _assert2.default.throws(function () {
      (0, _2.default)();
    }, Error, 'src not given');
  });

  it('does not throw with jsx in a module', function () {
    _assert2.default.doesNotThrow(function () {
      (0, _2.default)("import foo from 'foo'; var baz = <baz>bar;");
    });
  });
}); /* eslint-env mocha */
//# sourceMappingURL=index.spec.js.map